ecsalt_component (ecsalt v2.0.1)
View SourcePut, remove, and query named data on entities.
Summary
Functions
Fold a function over all entities matching a given set of components, accumulating a result.
For each entity with the specified Component, apply fun(EntityID, Values).
Return all entities matching a given set of components. Returns empty list if there are no matches.
Associate a component defined as the tuple {key,value} with an entity. If the component already exists, it will be replaced with the new value. Returns the opaque world() type.
Remove a component from a given entity. This function will always succeed even if the component does not exist.
Update a component's value by applying a function to it. The component must already exist on the entity.
Types
Functions
Fold a function over all entities matching a given set of components, accumulating a result.
For each entity with the specified Component, apply fun(EntityID, Values).
Return all entities matching a given set of components. Returns empty list if there are no matches.
Associate a component defined as the tuple {key,value} with an entity. If the component already exists, it will be replaced with the new value. Returns the opaque world() type.
Remove a component from a given entity. This function will always succeed even if the component does not exist.
Update a component's value by applying a function to it. The component must already exist on the entity.