ecsalt_system behaviour (ecsalt v2.0.1)
View SourceRegister, list, and unregister callbacks
Summary
Functions
List all registered systems and their relative priority
Register a callback of the form {module, fun, 2} or fun(M,N) that will accept Data as the first argument and the World reference as the second argument.
The same as register/2, but priority may also be specified. Negative values are higher priority.
Remove a system from the ECS world.
Types
Callbacks
-callback proc(Data :: term(), World :: ecsalt:world()) -> term().
Functions
List all registered systems and their relative priority
Register a callback of the form {module, fun, 2} or fun(M,N) that will accept Data as the first argument and the World reference as the second argument.
The same as register/2, but priority may also be specified. Negative values are higher priority.
Remove a system from the ECS world.